@@ -25,7 +25,6 @@ import bas_remote.bas_def;
 
 public class ConfigUnitJApplet extends JApplet
 {
-	private JTextField EbxSysReadMax;
 	private JTextField EbxMstpNetwork;
 	private JTextField EbxSysReadDelay;
 	private JTextField EbxOflPollDelay;
@@ -50,7 +49,7 @@ public class ConfigUnitJApplet extends JApplet
 	    */
 		private String             hostAddress;
 	    static boolean             dbug_on             = false;
-	    static String              dbug_ip             = "192.168.92.68";
+	    static String              dbug_ip             = "192.168.92.150";
 	    static int                 dbug_unit           = 1;
 	    //
 	    private mod.device         comBas              = new mod.device();
@@ -232,9 +231,6 @@ public class ConfigUnitJApplet extends JApplet
 	            EbxOflPollDelay.setText((tmp = comBas.ReadCfgStr(bas_def.REG_SYS_POLL_OFFLINE)));
 	            // System poll delay.
 	            EbxSysReadDelay.setText((tmp = comBas.ReadCfgStr(bas_def.REG_SYS_READ_DELAY)));
-	            // Inter-frame gap.
-	            EbxSysReadMax.setText((tmp = comBas.ReadCfgStr(bas_def.REG_SYS_READ_MAX)));
-	            //EbxIfGap.setText((tmp = comBas.ReadCfgStr(bas_def.REG_SYS_IFGAP)));
 	            //
 	            // Bacnet data.
 	            //
@@ -468,24 +464,7 @@ public class ConfigUnitJApplet extends JApplet
 	            LblError.setVisible(true);
 	            return;
 	        }
-	        i = Integer.decode(EbxSysReadMax.getText());
-	        if ((i < 1) || (i > 125))
-	        {
-	            EbxSysReadMax.requestFocusInWindow();
-	            LblError.setText("Value out of range (1<>125)");
-	            LblError.setVisible(true);
-	            return;
-	        }
-	        /*
-	        i = Integer.decode(EbxIfGap.getText());
-	        if ((i < 0) || (i > 100))
-	        {
-	            EbxIfGap.requestFocusInWindow();
-	            LblError.setText("Time value out of range (0<>100)");
-	            LblError.setVisible(true);
-	            return;
-	        }
-	        */
+
 	        i = Integer.decode(EbxTimeout.getText());
 	        if ((i < 50) || (i > 3000))
 	        {
@@ -601,11 +580,6 @@ public class ConfigUnitJApplet extends JApplet
 	            comBas.WriteCfg(bas_def.REG_SYS_POLL_OFFLINE, EbxOflPollDelay.getText());
 	            // Consecutive read delay.
 	            comBas.WriteCfg(bas_def.REG_SYS_READ_DELAY, EbxSysReadDelay.getText());
-	            // Max consecutive reads.
-	            comBas.WriteCfg(bas_def.REG_SYS_READ_MAX, EbxSysReadMax.getText());
-	            // Inter-frame gap.
-	            //comBas.WriteCfg(bas_def.REG_SYS_IFGAP, EbxIfGap.getText());
-	            
 	            // ---------------------------------------------------------------------
 	            // Save new configuration.
 	            // Extend timeout for this operation, then reset to default value.
@@ -854,17 +828,6 @@ public class ConfigUnitJApplet extends JApplet
 			BnUpdateCfg.setText("Save");
 			BnUpdateCfg.setBounds(21, 666, 122, 24);
 			getContentPane().add(BnUpdateCfg);
-			
-			final JLabel consecutiveDelayMaxLabel = new JLabel();
-			consecutiveDelayMaxLabel.setFont(new Font("Dialog", Font.PLAIN, 12));
-			consecutiveDelayMaxLabel.setText("Max Consecutive RD:");
-			consecutiveDelayMaxLabel.setBounds(21, 619, 150, 14);
-			getContentPane().add(consecutiveDelayMaxLabel);
-
-			EbxSysReadMax = new JTextField();
-			EbxSysReadMax.setText("EbxSysReadMax");
-			EbxSysReadMax.setBounds(181, 617, 144, 18);
-			getContentPane().add(EbxSysReadMax);
 
 			final JPanel notePanel = new JPanel();
 			notePanel.setBorder(new TitledBorder(null, "NOTE", TitledBorder.DEFAULT_JUSTIFICATION, TitledBorder.DEFAULT_POSITION, null, Color.BLACK));
