@@ -2,6 +2,7 @@ package MappingCfg;
 
 import java.awt.BorderLayout;
 import java.awt.Color;
+import java.awt.Dimension;
 import java.awt.Font;
 import java.awt.event.ActionEvent;
 import java.awt.event.ActionListener;
@@ -40,20 +41,18 @@ class dev_data
     	int			i;
     	
     	
-    	local = modAddr;
-    	if(modAddr.length() < 3)
+    	if(modAddr.length() >= 19)
+    		local = modAddr.substring(0, 19) + " ";
+    	else
     	{
-    		for(i = 0; i < (3 - modAddr.length()); i++)
+        	local = modAddr;
+    		for(i = 0; i < (19 - modAddr.length()); i++)
     			tmp += " ";
     		local = local.concat(tmp);
-    		local = local.concat("      ");
+    		local = local.concat(" "); 
     	}
-    	else if(modAddr.length() > 4)
-    		local = local.concat("  ");   
-    	else
-    		local = local.concat("      ");       		
-    	
-    	tmp = "";   	
+
+    	tmp = "";  	
     	if(instance.length() > 7)
     		local = local.concat(instance.substring(0, 7));
     	else
@@ -100,7 +99,7 @@ public class MappingCfgApplet extends JApplet
     private JTextField ebxDevNumber;
     private String            	hostAddress;
     static boolean           	dbug_on        	= false;
-    static String             	dbug_ip        	= "192.168.92.68";
+    static String             	dbug_ip        	= "10.0.0.240";
     static int                	dbug_unit      	= 1;
     private mod.device        	comBas         	= new mod.device();
     int							devNumber    	= 0;
@@ -124,7 +123,7 @@ public class MappingCfgApplet extends JApplet
     private JButton 			addButton 		= new JButton();
     private JButton 			modifyButton 	= new JButton();
     private JButton 			deleteButton 	= new JButton();
-
+    private	devProfilePanel		devProfilePanel1;
     //
     private boolean            	update_in_process   = false;
     String						password		= "ccsi2431";
@@ -136,7 +135,7 @@ public class MappingCfgApplet extends JApplet
 	public MappingCfgApplet() 
 	{
 		super();
-		setSize(547, 490);
+		setSize(598, 497);
         initComponents();
 	}
 
@@ -276,10 +275,21 @@ public class MappingCfgApplet extends JApplet
                     panel.repaint();
             	}
             	
-                try
+            	else if(cmuFlag.is_exit_profile_panel_select() == true)
+            	{
+            		cmuFlag.clear_exit_profile_panel();
+                    panel.removeAll();
+                    //panel.remove(devicePanel1);
+                    panel.add(scrollPane , BorderLayout.CENTER);
+                    panel.validate();
+                    panel.repaint();
+            	}
+
+            	try
                 {
                     Thread.sleep(300);
-                } catch (InterruptedException e)
+                } 
+            	catch (InterruptedException e)
                 {
                 }
             }
@@ -399,16 +409,17 @@ public class MappingCfgApplet extends JApplet
     private void initComponents()
     {
         contentPanel = new JPanel();
+        contentPanel.setPreferredSize(new Dimension(900, 500));
         contentPanel.setLayout(null);
         setContentPane(contentPanel);
 		
         panel = new JPanel(); // 
 		panel.setLayout(null);
-		panel.setBounds(10, 10, 527, 480);
+		panel.setBounds(10, 10, 588, 487);
 		contentPanel.add(panel);  
 		
 		scrollPane = new JScrollPane();
-		scrollPane.setBounds(0, 0, 527, 480);
+		scrollPane.setBounds(0, 0, 588, 480);
         panel.add(scrollPane);
 
 		cfgPanel = new JPanel();
@@ -426,19 +437,19 @@ public class MappingCfgApplet extends JApplet
 		final JLabel instanceLabel = new JLabel();
 		instanceLabel.setFont(new Font("Sans", Font.BOLD, 12));
 		instanceLabel.setText("Instance");
-		instanceLabel.setBounds(80, 53, 70, 14);
+		instanceLabel.setBounds(148, 53, 70, 14);
 		cfgPanel.add(instanceLabel);
 
 		final JLabel nameLabel = new JLabel();
 		nameLabel.setFont(new Font("Sans", Font.BOLD, 12));
 		nameLabel.setText("Name");
-		nameLabel.setBounds(210, 53, 51, 14);
+		nameLabel.setBounds(258, 53, 51, 14);
 		cfgPanel.add(nameLabel);
 
 		final JLabel typeLabel = new JLabel();
 		typeLabel.setFont(new Font("Sans", Font.BOLD, 12));
 		typeLabel.setText("Type");
-		typeLabel.setBounds(433, 53, 42, 14);
+		typeLabel.setBounds(469, 53, 42, 14);
 		cfgPanel.add(typeLabel);
 
 		errorLabel = new JLabel();
@@ -495,7 +506,7 @@ public class MappingCfgApplet extends JApplet
         });
 		
 		final JScrollPane scrollPane_1 = new JScrollPane(list);
-		scrollPane_1.setBounds(10, 73, 507, 306);
+		scrollPane_1.setBounds(10, 73, 565, 306);
 		cfgPanel.add(scrollPane_1);
 		
 		addButton.addActionListener(new ActionListener() 
@@ -511,7 +522,7 @@ public class MappingCfgApplet extends JApplet
 			}
 		});
 		addButton.setText("Add");
-		addButton.setBounds(26, 412, 70, 24);
+		addButton.setBounds(26, 412, 65, 25);
 		cfgPanel.add(addButton);
 
 		deleteButton.addActionListener(new ActionListener() 
@@ -564,7 +575,7 @@ public class MappingCfgApplet extends JApplet
 			}
 		});
 		deleteButton.setText("Delete");
-		deleteButton.setBounds(363, 412, 82, 24);
+		deleteButton.setBounds(327, 412, 85, 25);
 		cfgPanel.add(deleteButton);
 
 		modifyButton.addActionListener(new ActionListener() 
@@ -619,7 +630,7 @@ public class MappingCfgApplet extends JApplet
 			}
 		});
 		modifyButton.setText("Modify");
-		modifyButton.setBounds(230, 412, 88, 24);
+		modifyButton.setBounds(214, 412, 85, 25);
 		cfgPanel.add(modifyButton);
 
 		copyButton.addActionListener(new ActionListener() 
@@ -673,7 +684,7 @@ public class MappingCfgApplet extends JApplet
 			}
 		});
 		copyButton.setText("Copy");
-		copyButton.setBounds(130, 412, 70, 24);
+		copyButton.setBounds(117, 412, 70, 25);
 		cfgPanel.add(copyButton);
 		
 		updateButton.addActionListener(new ActionListener() 
@@ -720,6 +731,23 @@ public class MappingCfgApplet extends JApplet
 		ebxObjNumber.setBounds(363, 29, 58, 18);
 		ebxObjNumber.setEditable(false);
 		cfgPanel.add(ebxObjNumber);
+
+		final JButton deviceProfileButton = new JButton();
+		deviceProfileButton.addActionListener(new ActionListener() 
+		{
+			public void actionPerformed(final ActionEvent arg0) 
+			{
+				devProfilePanel1 = new devProfilePanel();
+                panel.remove(scrollPane);
+                devProfilePanel1.comBas = comBas;
+                panel.add(devProfilePanel1 , BorderLayout.CENTER);
+                panel.validate();
+                panel.repaint();
+			}
+		});
+		deviceProfileButton.setText("Device Profile");
+		deviceProfileButton.setBounds(437, 412, 135, 25);
+		cfgPanel.add(deviceProfileButton);
     }
 }
 
