@@ -32,22 +32,22 @@ import bas_remote.*;
 public class ModbusMappingApplet extends JApplet
 {
 
-    private JTextField EbxModAddr;
-    private JComboBox CbxDevInstance;
+    private JTextField 	EbxModAddr;
+	private JComboBox 	CbxDevInstance;
     /**
 	 * 
 	 */
-    private static final long serialVersionUID   = 1L;
-    private JList             overallStatusList;
-    private JLabel            errorLabel;
-    private DefaultListModel  listModel;
+    private static final long 	serialVersionUID   = 1L;
+	private JList				overallStatusList;
+    private JLabel            	errorLabel;
+	private DefaultListModel  	listModel;
 
     /**
      * Member variables.
      */
     private String            hostAddress;
     static boolean            dbug_on            = false;
-    static String             dbug_ip            = "192.168.92.68";
+    static String             dbug_ip            = "10.0.0.240";
     static int                dbug_unit          = 1;
     private mod.device        comBas             = new mod.device();
     //    
@@ -61,8 +61,8 @@ public class ModbusMappingApplet extends JApplet
     private ConnectTask       connect_task       = new ConnectTask();
 
     private final JPanel      PnlStatus          = new JPanel();
-    private final JComboBox   CbxInstance        = new JComboBox();
-    private final JComboBox   CbxProperty        = new JComboBox();
+	private final JComboBox   CbxInstance        = new JComboBox();
+	private final JComboBox   CbxProperty        = new JComboBox();
     private final JTextField  EbxPropVal         = new JTextField();
     private final JLabel      propertyValueLabel = new JLabel();
     private final JScrollPane ScpStatus          = new JScrollPane();
@@ -84,19 +84,31 @@ public class ModbusMappingApplet extends JApplet
         	switch (type)
         	{
         		case ANALOG_INPUT:
-        			t = "AI";
+        			t = "AI  ";
         			break;
         		case ANALOG_OUTPUT:
-        			t = "AO";
+        			t = "AO  ";
         			break;
         		case ANALOG_VALUE:
-        			t = "AV";
+        			t = "AV  ";
         			break;
         		case BINARY_INPUT:
-        			t = "BI";
+        			t = "BI  ";
         			break;
         		case BINARY_OUTPUT:
-        			t = "BO";
+        			t = "BO  ";
+        			break;
+        		case INT_VALUE_RO:
+        			t = "IVRO";
+        			break;
+        		case INT_VALUE_RW:
+        			t = "IVRW";
+        			break;
+        		case UINT_VALUE_RO:
+        			t = "UVRO";
+        			break;
+        		case UINT_VALUE_RW:
+        			t = "UVRW";
         			break;
         	}
         	i = "        " + instance;
@@ -146,7 +158,7 @@ public class ModbusMappingApplet extends JApplet
     	}
     }
 
-    public class MyCellRenderer extends JLabel implements ListCellRenderer
+	public class MyCellRenderer extends JLabel implements ListCellRenderer
     {
 
     	/**
@@ -199,7 +211,7 @@ public class ModbusMappingApplet extends JApplet
         initComponents();
     }
 
-    public void init()
+	public void init()
     {
         // Get code base string.
         hostAddress = this.getCodeBase().toString().toLowerCase();
@@ -327,7 +339,7 @@ public class ModbusMappingApplet extends JApplet
     }
 
     // get device instance for all units
-    private void GetInstanceValues()
+	private void GetInstanceValues()
     {
         int 		cnt;
         String		dd;
@@ -389,7 +401,7 @@ public class ModbusMappingApplet extends JApplet
 		EbxModAddr.setText(modAddr);
 	}
 	
-    private void GetObjInstanceValues(int index)
+	private void GetObjInstanceValues(int index)
     {
         int 		i, obj_qty = 0;
         obj_data 	od;
@@ -430,7 +442,8 @@ public class ModbusMappingApplet extends JApplet
         	{
                 synchronized(this)
                 {
-                	od.type = bac.type.getType(comBas.ReadObjIntX(index, i, bac.def.OBJECT_TYPE));
+                	int tmp = comBas.ReadObjIntX(index, i, bac.def.OBJECT_TYPE);
+                	od.type = bac.type.getType(tmp);
                 }
 			} 
         	catch (IOException e) 
@@ -709,7 +722,7 @@ public class ModbusMappingApplet extends JApplet
         }
     }
 
-    private void initComponents()
+	private void initComponents()
     {
         final JButton BnRead = new JButton();
         BnRead.addActionListener(new ActionListener() {
