@@ -24,6 +24,7 @@ import bas_remote.bas_def;
 public class addPanel extends JPanel
 {
 
+	private JTextField EbxConsecutive;
 	private JTextField EbxModIpAddr;
 	private JTextField EbxRegNumber;
 	private JButton 	cancelButton;
@@ -192,6 +193,8 @@ public class addPanel extends JPanel
         String		modAddr = null, reg = null;
         int			iModAddr = 0;
         String		comModAddr = null;
+        String		rd = null;
+        int			rd_group = 0;
         
         // Return if not connected.
         if (!comBas.IsConnected())
@@ -287,6 +290,10 @@ public class addPanel extends JPanel
         		        JOptionPane.showMessageDialog(null, errorMsg);
         		        return;
         			}
+                	if(fileFunction.unit_name.equals("Modbus Unit 2450246"))
+                	{
+                		fileFunction.unit_name = "Modbus Unit " + instance;
+                	}
         			modIP = EbxModIpAddr.getText();
     				fileFunction.mod_ip = modIP;
         			if(validateIPAddress(modIP) == 0)
@@ -317,7 +324,16 @@ public class addPanel extends JPanel
         		        JOptionPane.showMessageDialog(null, errorMsg);
         		        return;
         			}
-        					
+        			
+        			rd = EbxConsecutive.getText();
+    				fileFunction.consecutive_rd = rd;
+    				rd_group = Integer.valueOf(rd);
+    				if((rd_group < 1) || (rd_group > fileFunction.MAX_RD))
+    				{
+     					errorMsg = "Error: Invalid Consecutive Reads";      
+        		        JOptionPane.showMessageDialog(null, errorMsg);
+        		        return;   					
+    				}
         			// write to server
         			if((fullDstName != null) && (error == false))
         			{
@@ -434,7 +450,7 @@ public class addPanel extends JPanel
     	int		i;
     	
 		setLayout(null);
-		setBounds(10, 10, 418, 475);
+		setBounds(10, 10, 433, 475);
 
 		final JLabel label = new JLabel();
 		label.setFont(new Font("Sans", Font.PLAIN, 12));
@@ -456,9 +472,9 @@ public class addPanel extends JPanel
 		add(nameLabel);
 
 		EbxDevName = new JTextField();
-		EbxDevName.setText("Default Modbus Unit Name");
+		EbxDevName.setText("Modbus Unit 2450246");
 		EbxDevName.setBorder(new BevelBorder(BevelBorder.LOWERED));
-		EbxDevName.setBounds(77, 50, 220, 22);
+		EbxDevName.setBounds(77, 50, 289, 22);
 		add(EbxDevName);
 
 		final JLabel modbusAddressLabel = new JLabel();
@@ -719,6 +735,18 @@ public class addPanel extends JPanel
 		EbxModIpAddr.setBorder(new BevelBorder(BevelBorder.LOWERED));
 		EbxModIpAddr.setBounds(175, 118, 151, 22);
 		add(EbxModIpAddr);
+
+		final JLabel consecutiverdLabel = new JLabel();
+		consecutiverdLabel.setFont(new Font("Sans", Font.PLAIN, 12));
+		consecutiverdLabel.setText("MAX Consecutive RD");
+		consecutiverdLabel.setBounds(257, 85, 131, 14);
+		add(consecutiverdLabel);
+
+		EbxConsecutive = new JTextField();
+		EbxConsecutive.setText("1");
+		EbxConsecutive.setBorder(new BevelBorder(BevelBorder.LOWERED));
+		EbxConsecutive.setBounds(391, 82, 32, 21);
+		add(EbxConsecutive);
     }
 
 }
