@@ -47,26 +47,18 @@ public class bac
         public final static int BAC_MOD_DEV_NAME	= 0xff0e;
         public final static int BAC_MOD_TYPE		= 0xff0f;
         //
-        // Numeric values for various object types.
+        // Numeric values for various object types - only for our own purpose
         //
-        public final static int ANALOG_INPUT        = 0;
-        public final static int ANALOG_OUTPUT       = 1;
-        public final static int ANALOG_VALUE        = 2;
-        public final static int BINARY_INPUT        = 3;
-        public final static int BINARY_OUTPUT       = 4;
-        public final static int BINARY_VALUE        = 5;
-        public final static int CALENDAR            = 6;
-        public final static int COMMAND             = 7;
-        public final static int DEVICE              = 8;
-        public final static int EVENT_ENROLLMENT    = 9;
-        public final static int FILE_0              = 10;
-        public final static int GROUP               = 11;
-        public final static int LOOP                = 12;
-        public final static int MULTI_STATE_INPUT   = 13;
-        public final static int MULTI_STATE_OUTPUT  = 14;
-        public final static int NOTIFICATION_CLASS  = 15;
-        public final static int PROGRAM             = 16;
-        public final static int SCHEDULE            = 17;
+        public final static int ANALOG_INPUT        	= 0;
+        public final static int ANALOG_OUTPUT       	= 1;
+        public final static int ANALOG_VALUE       	 	= 2;
+        public final static int BINARY_INPUT        	= 3;
+        public final static int BINARY_OUTPUT       	= 4;
+        public final static int BINARY_VALUE        	= 5;
+        public final static int INTEGER_VALUE_RO       	= 6;
+        public final static int INTEGER_VALUE_RW       	= 7;
+        public final static int POSITIVE_VALUE_RO  		= 8;        
+        public final static int POSITIVE_VALUE_RW  		= 9;        
     }
 
     /**
@@ -130,12 +122,16 @@ public class bac
      */
     public enum type
     {
-        ANALOG_INPUT        ("Analog Input",    def.ANALOG_INPUT),
-        ANALOG_OUTPUT       ("Analog Output",   def.ANALOG_OUTPUT),
-        ANALOG_VALUE        ("Analog Value",    def.ANALOG_VALUE),
-        BINARY_INPUT        ("Binary Input",    def.BINARY_INPUT),
-        BINARY_OUTPUT       ("Binary Output",   def.BINARY_OUTPUT),
-        //BINARY_VALUE        ("Binary Value",    def.BINARY_VALUE),
+        ANALOG_INPUT        ("Analog Input",    	def.ANALOG_INPUT),
+        ANALOG_OUTPUT       ("Analog Output",   	def.ANALOG_OUTPUT),
+        ANALOG_VALUE        ("Analog Value",    	def.ANALOG_VALUE),
+        BINARY_INPUT        ("Binary Input",    	def.BINARY_INPUT),
+        BINARY_OUTPUT       ("Binary Output",   	def.BINARY_OUTPUT),
+        BINARY_VALUE        ("Binary Value",    	def.BINARY_VALUE),
+        INT_VALUE_RO        ("Integer Value RO",    def.INTEGER_VALUE_RO),
+        INT_VALUE_RW        ("Integer Value RW",   	def.INTEGER_VALUE_RW),
+        UINT_VALUE_RO       ("Positive Value RO",   def.POSITIVE_VALUE_RO),
+        UINT_VALUE_RW       ("Positive Value RW",   def.POSITIVE_VALUE_RW),
         ;
         
         private String    enum_txt;
