@@ -5,6 +5,7 @@ public class cmuFlag {
 	static boolean		exit_modify_panel;
 	static boolean		exit_copy_panel;
 	static boolean		exit_device_panel;
+	static boolean		exit_profile_panel;
 	
 	public static void init()
 	{
@@ -12,6 +13,7 @@ public class cmuFlag {
 		exit_modify_panel = false;
 		exit_copy_panel = false;
 		exit_device_panel = false;
+		exit_profile_panel = false;
 	}
 	
 	public static void set_exit_add_panel()
@@ -77,4 +79,20 @@ public class cmuFlag {
 		else
 			return false;
 	}
+
+	public static void set_exit_profile_panel()
+	{
+		exit_profile_panel = true;		
+	}
+	public static void clear_exit_profile_panel()
+	{
+		exit_profile_panel = false;		
+	}
+	public static boolean is_exit_profile_panel_select()
+	{
+		if(exit_profile_panel == true )
+			return true;
+		else
+			return false;
+	}
 }
