@@ -25,6 +25,7 @@ import bas_remote.bas_def;
 public class copyPanel extends JPanel
 {
 
+	private JTextField EbxConsecutive;
 	private JTextField EbxRegNumber;
 	private JTextField EbxModIP;
 	private JLabel 		errorLabel;
@@ -46,6 +47,7 @@ public class copyPanel extends JPanel
     String				filename		= null;
     int					objStatus[];
     String				password		= "ccsi2431";
+ 	String				tmp;
  	
 	public copyPanel()
 	{
@@ -123,6 +125,8 @@ public class copyPanel extends JPanel
         int					iModAddr = 0;
         String				comModAddr = null;
 		String				modIP = null, reg;
+        String				rd = null;
+        int					rd_group = 0;
 		
         // Return if not connected.
         if (!comBas.IsConnected())
@@ -133,10 +137,16 @@ public class copyPanel extends JPanel
 			fileFunction.unit_name = EbxDeviceName.getText();
 	        if(fileFunction.unit_name.equals("") || (fileFunction.unit_name == null))
 	        {
-	            errorMsg = "Error: No Unit Name";   
+	            errorMsg = "Error: No Unit Name!";   
 		        JOptionPane.showMessageDialog(null, errorMsg);
 		        return;
 	        }
+	        else if(tmp.equals(fileFunction.unit_name))
+	        {
+	            errorMsg = "Error: Unit Name already exist!";   
+		        JOptionPane.showMessageDialog(null, errorMsg);
+		        return;	        	
+	        }
 			
 			modAddr = EbxModAddr.getText();
 			try
@@ -288,7 +298,17 @@ public class copyPanel extends JPanel
 								return;									
 							}
 							
-							ip = comBas.ReadCfgStr(bas_def.REG_SYS_IPADDR);
+		        			rd = EbxConsecutive.getText();
+		    				fileFunction.consecutive_rd = rd;
+		    				rd_group = Integer.valueOf(rd);
+		    				if((rd_group < 1) || (rd_group > fileFunction.MAX_RD))
+		    				{
+		     					errorMsg = "Error: Invalid Consecutive Reads";      
+		        		        JOptionPane.showMessageDialog(null, errorMsg);
+		        		        return;   					
+		    				}
+
+		    				ip = comBas.ReadCfgStr(bas_def.REG_SYS_IPADDR);
 							st = new StringTokenizer(fileFunction.devType, ",");
 							if(st.hasMoreTokens())
 								deviceType = st.nextToken();
@@ -351,10 +371,12 @@ public class copyPanel extends JPanel
         int			i;
         
 		// Get object data.
+        tmp = fileFunction.unit_name;
 		EbxDeviceName.setText(fileFunction.unit_name);
 		EbxModAddr.setText(fileFunction.mod_address);
 		EbxDevInst.setText(fileFunction.unit_instance);
 		EbxModIP.setText(fileFunction.mod_ip);
+		EbxConsecutive.setText(fileFunction.consecutive_rd);
 	    obj_qty = fileFunction.reg_qty;
 	    if(obj_qty > 1000)
 	    	obj_qty = 1000;
@@ -419,7 +441,7 @@ public class copyPanel extends JPanel
 	private void initComponents()
     {
 		setLayout(null);
-		setBounds(10, 10, 418, 475);
+		setBounds(10, 10, 475, 475);
 
 		final JLabel nameLabel = new JLabel();
 		nameLabel.setFont(new Font("Sans", Font.PLAIN, 12));
@@ -659,6 +681,17 @@ public class copyPanel extends JPanel
 		label.setBounds(210, 80, 77, 14);
 		add(label);
 
+		final JLabel consectiveRdLabel = new JLabel();
+		consectiveRdLabel.setFont(new Font("Sans", Font.PLAIN, 12));
+		consectiveRdLabel.setText("MAX Consecutive RD");
+		consectiveRdLabel.setBounds(290, 80, 130, 14);
+		add(consectiveRdLabel);
+
+		EbxConsecutive = new JTextField();
+		EbxConsecutive.setText("1");
+		EbxConsecutive.setBorder(new BevelBorder(BevelBorder.LOWERED));
+		EbxConsecutive.setBounds(424, 77, 37, 21);
+		add(EbxConsecutive);
     }
 }
 
