@@ -193,6 +193,13 @@ public class mod
         // Rsp : S F C c..c\0 c..c\0... (Success)
         // Rsp : S F R (Failure)
         //
+        public static final byte	    READ_COILS_MTCP 			= (byte)115;
+        public static final byte	    READ_DISCRETE_INPUTS_MTCP 	= (byte)116;
+        public static final byte	    READ_HOLDING_REGISTERS_MTCP = (byte)117;
+        public static final byte	    READ_INPUT_REGISTERS_MTCP 	= (byte)118;
+        public static final byte	    WRITE_SINGLE_COIL_MTCP 		= (byte)119;
+        public static final byte	    WRITE_MULTIPLE_REGISTERS_MTCP = (byte)120;
+        //
         // Modbus error codes.
         //
         public final static byte UNKNOWN_ERROR            = 0;
@@ -1024,6 +1031,50 @@ public class mod
                     }
                     break;
                 //
+                case def.READ_COILS_MTCP:
+                case def.READ_DISCRETE_INPUTS_MTCP:
+                case def.READ_HOLDING_REGISTERS_MTCP:
+                case def.READ_INPUT_REGISTERS_MTCP:
+                    //
+                    // Store item quantity.
+                    xxBuf[xx_idx++] = (byte) (pkt.itm_qty >> 8);
+                    xxBuf[xx_idx++] = (byte) pkt.itm_qty;
+                    for(i = 0; i < 4; i++)
+                    	xxBuf[xx_idx++] = (byte) pkt.b[i];
+                    //
+                    break;
+                    //
+                case def.WRITE_SINGLE_COIL_MTCP:
+                    //
+                    // Store data. '1' is 0xff00.
+                    if (pkt.b[0] != 0)
+                        tmpval = 0x0ff00;
+                    else
+                        tmpval = 0;
+                    xxBuf[xx_idx++] = (byte) (tmpval >> 8);
+                    xxBuf[xx_idx++] = (byte) tmpval;
+                    for(i = 0; i < 4; i++)
+                    	xxBuf[xx_idx++] = (byte) pkt.b[i + 1];                    
+                    //
+                    break;
+                    //
+                case def.WRITE_MULTIPLE_REGISTERS_MTCP:
+                    //
+                    // Store item quantity.
+                    xxBuf[xx_idx++] = (byte) (pkt.itm_qty >> 8);
+                    xxBuf[xx_idx++] = (byte) pkt.itm_qty;
+                    // Store number of bytes.
+                    xxBuf[xx_idx++] = (byte) (pkt.itm_qty * 2);
+                    // Store data.
+                    for (i = 0; i < pkt.itm_qty; ++i)
+                    {
+                        xxBuf[xx_idx++] = (byte) (pkt.w[i] >> 8);
+                        xxBuf[xx_idx++] = (byte) pkt.w[i];
+                    }
+                    for(i = 0; i < 4; i++)
+                    	xxBuf[xx_idx++] = (byte) pkt.b[pkt.itm_qty * 2 + i];                    
+                    //
+                    break;
                 default:
                     //
                     // Throw error.
@@ -1102,6 +1153,8 @@ public class mod
                 //
                 case def.READ_COILS:
                 case def.READ_DISCRETE_INPUTS:
+                case def.READ_COILS_MTCP:
+                case def.READ_DISCRETE_INPUTS_MTCP:
                     //
                     // Skip byte count.
                     ++rx_idx;
@@ -1126,6 +1179,8 @@ public class mod
                 //
                 case def.READ_HOLDING_REGISTERS:
                 case def.READ_INPUT_REGISTERS:
+                case def.READ_HOLDING_REGISTERS_MTCP:
+                case def.READ_INPUT_REGISTERS_MTCP:
                     //
                     // Skip byte count.
                     ++rx_idx;
@@ -1522,6 +1577,27 @@ public class mod
             }
         }
 
+        public int ReadCoilMTCP( int slave , int reg , byte[] ip) throws IOException
+        {
+            pkt.slv_adr = (byte) slave;
+            pkt.fcn = (byte) mod_def.READ_COILS_MTCP;
+            pkt.itm_adr = (short) reg;
+            pkt.itm_qty = 1;
+            
+            for(int i = 0; i < 4; i++)
+            	pkt.b[i] = ip[i];
+            try
+            {
+                trf.MasterTx(pkt);
+                if (pkt.b[0] > 0)
+                    return 1;
+                else
+                    return 0;
+            } catch (IOException e)
+            {
+                throw e;
+            }
+        }
         public int WriteCoil( int slave , int reg , int val ) throws IOException
         {
             pkt.slv_adr = (byte) slave;
@@ -1538,6 +1614,25 @@ public class mod
             }
         }
         
+        public int WriteCoilMTCP( int slave , int reg , byte[] ip, int val ) throws IOException
+        {
+            pkt.slv_adr = (byte) slave;
+            pkt.fcn = (byte) mod_def.WRITE_SINGLE_COIL_MTCP;
+            pkt.itm_adr = (short) reg;
+            pkt.itm_qty = 1;
+            pkt.b[0] = (byte) val;
+            for(int i = 0; i < 4; i++)
+            	pkt.b[i + 1] = ip[i];
+            
+            try
+            {
+                return trf.MasterTx(pkt);
+            } catch (IOException e)
+            {
+                throw e;
+            }
+        }
+
         public int ReadInp(int slave , int reg) throws IOException
         {
             pkt.slv_adr = (byte) slave;
@@ -1562,6 +1657,67 @@ public class mod
             }
         }
         
+        public int ReadInpMTCP(int slave , int reg, byte[] ip) throws IOException
+        {
+            pkt.slv_adr = (byte) slave;
+            pkt.fcn = (byte) mod_def.READ_DISCRETE_INPUTS_MTCP;
+            pkt.itm_adr = (short) reg;
+            pkt.itm_qty = 1;
+            for(int i = 0; i < 4; i++)
+            	pkt.b[i] = ip[i];
+            try
+            {
+                trf.MasterTx(pkt);
+                if ((pkt.b[0] & 1) > 0)
+                {
+                    return 1;
+                }
+                else
+                {
+                    return 0;
+                }
+            }
+            catch (IOException e)
+            {
+                throw e;
+            }
+        }
+
+        public int ReadRegInp16(int slave, int reg) throws IOException
+        {
+            pkt.slv_adr = (byte) slave;
+            pkt.fcn = (byte) mod_def.READ_INPUT_REGISTERS;
+            pkt.itm_adr = (short) reg;
+            pkt.itm_qty = 1;
+            try
+            {
+                trf.MasterTx(pkt);
+                return pkt.w[0] & 0x0ffff;
+            }
+            catch (IOException e)
+            {
+                throw e;
+            }
+        }
+        
+        public int ReadRegInp16MTCP(int slave, int reg, byte[] ip) throws IOException
+        {
+            pkt.slv_adr = (byte) slave;
+            pkt.fcn = (byte) mod_def.READ_INPUT_REGISTERS_MTCP;
+            pkt.itm_adr = (short) reg;
+            pkt.itm_qty = 1;
+            for(int i = 0; i < 4; i++)
+            	pkt.b[i] = ip[i];
+            try
+            {
+                trf.MasterTx(pkt);
+                return pkt.w[0] & 0x0ffff;
+            }
+            catch (IOException e)
+            {
+                throw e;
+            }
+        }
         /**
          * Reads an unsigned 16-bit value. Can be used with any Modbus device.
          * 
@@ -1587,6 +1743,24 @@ public class mod
             }
         }
         
+        public int ReadReg16MTCP(int slave, int reg, byte[] ip) throws IOException
+        {
+            pkt.slv_adr = (byte) slave;
+            pkt.fcn = (byte) mod_def.READ_HOLDING_REGISTERS_MTCP;
+            pkt.itm_adr = (short) reg;
+            pkt.itm_qty = 1;
+            for(int i = 0; i < 4; i++)
+            	pkt.b[i] = ip[i];
+            try
+            {
+                trf.MasterTx(pkt);
+                return pkt.w[0] & 0x0ffff;
+            }
+            catch (IOException e)
+            {
+                throw e;
+            }
+        }
         /**
          * Reads unsigned 16-bit values into an array of short integers.
          * Can be used with any Modbus device.
@@ -1680,6 +1854,71 @@ public class mod
             }
         }
         
+        public int WriteReg16MTCP(int slave, int reg, byte[] ip, int value[] , int qty) throws IOException
+        {
+            int             i;
+            
+            pkt.slv_adr = (byte) slave;
+            pkt.fcn = (byte) mod_def.WRITE_MULTIPLE_REGISTERS_MTCP;
+            pkt.itm_adr = (short) reg;
+            pkt.itm_qty = (short)qty;
+            for ( i = 0 ; i < pkt.itm_qty ; ++i )
+            {
+                pkt.w[i] = (short)value[i];
+            }
+            for(i = 0; i < 4; i++)
+            	pkt.b[qty * 2 + i] = ip[i];
+            
+            try
+            {
+                return trf.MasterTx(pkt);
+            }
+            catch (IOException e)
+            {
+                throw e;
+            }
+        }
+
+        public int RegInpPair(int slave, int reg, boolean write) throws IOException
+        {
+            pkt.slv_adr = (byte) slave;
+            if (write)
+                return -1;
+            else
+                pkt.fcn = (byte) mod_def.READ_INPUT_REGISTERS;
+            pkt.itm_adr = (short) reg;
+            pkt.itm_qty = 2;
+            try
+            {
+                return trf.MasterTx(pkt);
+            }
+            catch (IOException e)
+            {
+                throw e;
+            }
+        }
+
+        public int RegInpPairMTCP(int slave, int reg, byte[] ip, boolean write) throws IOException
+        {
+            pkt.slv_adr = (byte) slave;
+            if (write)
+                return -1;
+            else
+                pkt.fcn = (byte) mod_def.READ_INPUT_REGISTERS_MTCP;
+            pkt.itm_adr = (short) reg;
+            pkt.itm_qty = 2;
+            for(int i = 0; i < 4; i++)
+            	pkt.b[i] = ip[i];
+            try
+            {
+                return trf.MasterTx(pkt);
+            }
+            catch (IOException e)
+            {
+                throw e;
+            }
+        }
+
         /**
          * Reads or writes two consecutive registers.
          * 
@@ -1708,6 +1947,33 @@ public class mod
             }
         }
         
+        public int RegPairMTCP(int slave, int reg, byte[] ip, boolean write) throws IOException
+        {
+            pkt.slv_adr = (byte) slave;
+            if (write)
+            {
+                pkt.fcn = (byte) mod_def.WRITE_MULTIPLE_REGISTERS_MTCP;
+                for(int i = 0; i < 4; i++)
+                	pkt.b[i + 4] = ip[i];
+            }
+            else
+            {
+                pkt.fcn = (byte) mod_def.READ_HOLDING_REGISTERS_MTCP;
+                for(int i = 0; i < 4; i++)
+                	pkt.b[i] = ip[i];
+            }
+            pkt.itm_adr = (short) reg;
+            pkt.itm_qty = 2;
+            try
+            {
+                return trf.MasterTx(pkt);
+            }
+            catch (IOException e)
+            {
+                throw e;
+            }
+        }
+
         public int ReadRegPair(int slave, int reg, regOp32 rop) throws IOException
         {
             int val;
@@ -1739,6 +2005,99 @@ public class mod
             return 0;
         }
 
+        public int ReadRegPairMTCP(int slave, int reg, byte[] ip, regOp32 rop) throws IOException
+        {
+            int val;
+
+            try
+            {
+                RegPairMTCP(slave, reg, ip, false);
+            }
+            catch (IOException e)
+            {
+                throw e;
+            }
+            if (rop.big_endian)
+            {
+                val = pkt.w[0] & 0x0000ffff;
+                val <<= 16;
+                val |= pkt.w[1] & 0x0000ffff;
+            }
+            else
+            {
+                val = pkt.w[1] & 0x0000ffff;
+                val <<= 16;
+                val |= pkt.w[0] & 0x0000ffff;
+            }
+            if ( rop.float_op )
+                rop.f = Float.intBitsToFloat(val);
+            else
+                rop.i = val;
+            return 0;
+        }
+
+        public int ReadRegInpPair(int slave, int reg, regOp32 rop) throws IOException
+        {
+            int val;
+
+            try
+            {
+                RegInpPair(slave, reg, false);
+            }
+            catch (IOException e)
+            {
+                throw e;
+            }
+            if (rop.big_endian)
+            {
+                val = pkt.w[0] & 0x0000ffff;
+                val <<= 16;
+                val |= pkt.w[1] & 0x0000ffff;
+            }
+            else
+            {
+                val = pkt.w[1] & 0x0000ffff;
+                val <<= 16;
+                val |= pkt.w[0] & 0x0000ffff;
+            }
+            if ( rop.float_op )
+                rop.f = Float.intBitsToFloat(val);
+            else
+                rop.i = val;
+            return 0;
+        }
+
+        public int ReadRegInpPairMTCP(int slave, int reg, byte[] ip, regOp32 rop) throws IOException
+        {
+            int val;
+
+            try
+            {
+                RegInpPairMTCP(slave, reg, ip, false);
+            }
+            catch (IOException e)
+            {
+                throw e;
+            }
+            if (rop.big_endian)
+            {
+                val = pkt.w[0] & 0x0000ffff;
+                val <<= 16;
+                val |= pkt.w[1] & 0x0000ffff;
+            }
+            else
+            {
+                val = pkt.w[1] & 0x0000ffff;
+                val <<= 16;
+                val |= pkt.w[0] & 0x0000ffff;
+            }
+            if ( rop.float_op )
+                rop.f = Float.intBitsToFloat(val);
+            else
+                rop.i = val;
+            return 0;
+        }
+
         public int WriteRegPair(int slave, int reg, regOp32 rop) throws IOException
         {
             int val;
@@ -1767,6 +2126,34 @@ public class mod
             }
         }
 
+        public int WriteRegPairMTCP(int slave, int reg, byte[] ip, regOp32 rop) throws IOException
+        {
+            int val;
+
+            if (rop.float_op)
+                val = Float.floatToRawIntBits(rop.f);
+            else
+                val = rop.i;
+            if (rop.big_endian)
+            {
+                pkt.w[0] = (short) (val >> 16);
+                pkt.w[1] = (short) val;
+            }
+            else
+            {
+                pkt.w[0] = (short) val;
+                pkt.w[1] = (short) (val >> 16);
+            }
+            try
+            {
+                return RegPairMTCP(slave, reg, ip, true);
+            }
+            catch (IOException e)
+            {
+                throw e;
+            }
+        }
+
         public int ReadRegInt( int slv , int reg ) throws IOException
         {
             pkt.slv_adr = (byte) slv;
